|support| |donation| |docker_version| |pypi| |docker_pulls| |docker_stars| |license|


.. image:: https://gitlab.com/mayan-edms/mayan-edms/raw/master/docs/_static/mayan_logo.png
    :align: center
    :width: 200
    :height: 200

The most advanced open source document management system.


.. image:: https://gitlab.com/mayan-edms/mayan-edms/raw/master/docs/_static/overview.gif
    :align: center
    :width: 300

It is very easy to get started with Mayan EDMS, just deploy the official
Docker Compose file.

   .. code-block:: console

       curl https://gitlab.com/mayan-edms/mayan-edms/-/raw/master/docker/docker-compose.yml -O
       curl https://gitlab.com/mayan-edms/mayan-edms/-/raw/master/docker/.env -O
       docker compose up --detach


The complete documentation is available at: https://docs.mayan-edms.com/parts/installation.html

For more in-depth articles, tutorials, and troubleshooting available in the Knowledge Base.

.. image:: https://docs.mayan-edms.com/_static/knowledge-base.jpg
    :align: center
    :width: 300
    :target: https://sellfy.com/p/um2fkx/

Click the image or visit: https://forum.mayan-edms.com/s/prod_Ogq3lYaoROC02Q

Important links

- `Homepage <http://www.mayan-edms.com>`__
- `Documentation <https://docs.mayan-edms.com>`__
- `Contributing <https://gitlab.com/mayan-edms/mayan-edms/blob/master/CONTRIBUTING.md>`__
- `Forum <https://forum.mayan-edms.com>`__
- `Source code, issues, bugs <https://gitlab.com/mayan-edms/mayan-edms>`__
- `Plug-ins, other related projects <https://gitlab.com/mayan-edms/>`__
- `Translations <https://www.transifex.com/rosarior/mayan-edms/>`__
- `Videos <https://www.youtube.com/channel/UCJOOXHP1MJ9lVA7d8ZTlHPw>`__

.. |docker_version| image:: https://img.shields.io/docker/v/mayanedms/mayanedms?label=Docker
   :target: https://hub.docker.com/r/mayanedms/mayanedms
.. |donation| image:: https://img.shields.io/badge/donation-PayPal-brightgreen
   :target: https://paypal.me/MayanEDMS
.. |pypi| image:: https://img.shields.io/pypi/v/mayan-edms.svg
   :target: https://pypi.org/project/mayan-edms/
.. |builds| image:: https://gitlab.com/mayan-edms/mayan-edms/badges/master/build.svg
   :target: https://gitlab.com/mayan-edms/mayan-edms/pipelines
.. |license| image:: https://img.shields.io/pypi/l/mayan-edms.svg?style=flat
   :target: https://gitlab.com/mayan-edms/mayan-edms/blob/master/LICENSE
.. |docker_pulls| image:: https://img.shields.io/docker/pulls/mayanedms/mayanedms.svg
   :target: https://hub.docker.com/r/mayanedms/mayanedms/
.. |docker_stars| image:: https://img.shields.io/docker/stars/mayanedms/mayanedms.svg
   :target: https://hub.docker.com/r/mayanedms/mayanedms/
.. |docker_layers| image:: https://images.microbadger.com/badges/image/mayanedms/mayanedms.svg
   :target: https://microbadger.com/images/mayanedms/mayanedms
.. |support| image:: https://img.shields.io/badge/Get_support-brightgreen
   :target: https://www.mayan-edms.com/support/
